# Copyright 2016 The Meson development team

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
from ..mesonlib import is_windows

def destdir_join(d1, d2):
    # When the installation path starts with PREFIX, strip it away
    if d1 and is_windows() and 'MSYSTEM' in os.environ:
        assert os.path.isabs(d2) and 'MESON_INSTALL_PREFIX' in os.environ
        prefix = os.environ['MESON_INSTALL_PREFIX']
        rel_to_prefix = os.path.relpath(d2, prefix)
        if not rel_to_prefix.startswith(os.pardir + os.sep):
            return os.path.join(d1, rel_to_prefix)

    # c:\destdir + c:\prefix must produce c:\destdir\prefix
    if len(d1) > 1 and d1[1] == ':' \
            and len(d2) > 1 and d2[1] == ':':
        return d1 + d2[2:]
    return d1 + d2
